pub struct PortfolioStatistics {
pub pnls: AHashMap<String, AHashMap<String, f64>>,
pub returns: AHashMap<String, f64>,
pub general: AHashMap<String, f64>,
}Expand description
An owned snapshot of computed portfolio performance statistics.
pnls is keyed by currency code, each value mapping statistic name to value.
Fields
pnls: AHashMap<String, AHashMap<String, f64>>returns: AHashMap<String, f64>general: AHashMap<String, f64>Trait Implementations
Sourceimpl Clone for PortfolioStatistics
impl Clone for PortfolioStatistics
Sourcefn clone(&self) -> PortfolioStatistics
fn clone(&self) -> PortfolioStatistics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PortfolioStatistics
impl Debug for PortfolioStatistics
Sourceimpl Default for PortfolioStatistics
impl Default for PortfolioStatistics
Sourcefn default() -> PortfolioStatistics
fn default() -> PortfolioStatistics
Returns the “default value” for a type. Read more
impl DerefToPyAny for PortfolioStatistics
Sourceimpl<'py> IntoPyObject<'py> for PortfolioStatistics
impl<'py> IntoPyObject<'py> for PortfolioStatistics
Sourcetype Target = PortfolioStatistics
type Target = PortfolioStatistics
The Python output type
Sourcetype Output = Bound<'py, <PortfolioStatistics as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PortfolioStatistics as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PortfolioStatistics
impl PyClass for PortfolioStatistics
Sourceimpl PyClassImpl for PortfolioStatistics
impl PyClassImpl for PortfolioStatistics
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// An owned snapshot of computed portfolio performance statistics.
///
/// `pnls` is keyed by currency code, each value mapping statistic name to value.
const RAW_DOC: &'static CStr = /// An owned snapshot of computed portfolio performance statistics. /// /// `pnls` is keyed by currency code, each value mapping statistic name to value.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<PortfolioStatistics as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PortfolioStatistics>
type Layout = <<PortfolioStatistics as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<PortfolioStatistics>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPortfolioStatistics
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
fn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyStubType for PortfolioStatistics
impl PyStubType for PortfolioStatistics
Sourcefn type_output() -> TypeInfo
fn type_output() -> TypeInfo
The type to be used in the output signature, i.e. return type of the Python function or methods.
fn type_input() -> TypeInfo
fn type_input() -> TypeInfo
The type to be used in the input signature, i.e. the arguments of the Python function or methods. Read more
Sourceimpl PyTypeInfo for PortfolioStatistics
impl PyTypeInfo for PortfolioStatistics
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Auto Trait Implementations
impl Freeze for PortfolioStatistics
impl RefUnwindSafe for PortfolioStatistics
impl Send for PortfolioStatistics
impl Sync for PortfolioStatistics
impl Unpin for PortfolioStatistics
impl UnsafeUnpin for PortfolioStatistics
impl UnwindSafe for PortfolioStatistics